( cd usr/share/doc/HTML/da/k3b ; rm -rf common )
( cd usr/share/doc/HTML/da/k3b ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/de/k3b ; rm -rf common )
( cd usr/share/doc/HTML/de/k3b ; ln -sf /usr/share/doc/HTML/de/common common )
( cd usr/share/doc/HTML/es/k3b ; rm -rf common )
( cd usr/share/doc/HTML/es/k3b ; ln -sf /usr/share/doc/HTML/es/common common )
( cd usr/share/doc/HTML/et/k3b ; rm -rf common )
( cd usr/share/doc/HTML/et/k3b ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/share/doc/HTML/fr/k3b ; rm -rf common )
( cd usr/share/doc/HTML/fr/k3b ; ln -sf /usr/share/doc/HTML/fr/common common )
( cd usr/share/doc/HTML/it/k3b ; rm -rf common )
( cd usr/share/doc/HTML/it/k3b ; ln -sf /usr/share/doc/HTML/it/common common )
( cd usr/share/doc/HTML/nl/k3b ; rm -rf common )
( cd usr/share/doc/HTML/nl/k3b ; ln -sf /usr/share/doc/HTML/nl/common common )
( cd usr/share/doc/HTML/pl/k3b ; rm -rf common )
( cd usr/share/doc/HTML/pl/k3b ; ln -sf /usr/share/doc/HTML/pl/common common )
( cd usr/share/doc/HTML/pt/k3b ; rm -rf common )
( cd usr/share/doc/HTML/pt/k3b ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/share/doc/HTML/ru/k3b ; rm -rf common )
( cd usr/share/doc/HTML/ru/k3b ; ln -sf /usr/share/doc/HTML/ru/common common )
( cd usr/share/doc/HTML/sv/k3b ; rm -rf common )
( cd usr/share/doc/HTML/sv/k3b ; ln -sf /usr/share/doc/HTML/sv/common common )
( cd usr/share/doc/HTML/uk/k3b ; rm -rf common )
( cd usr/share/doc/HTML/uk/k3b ; ln -sf /usr/share/doc/HTML/uk/common common )
( cd usr/share/doc/HTML/pt_BR/k3b ; rm -rf common )
( cd usr/share/doc/HTML/pt_BR/k3b ; ln -sf /usr/share/doc/HTML/pt_BR/common common )
